# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-10-10 13:54
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Role',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='Role')),
                ('is_active', models.BooleanField(default=True)),
            ],
            options={
                'swappable': 'ARCTIC_ROLE_MODEL',
            },
        ),
        migrations.CreateModel(
            name='UserRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('role', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=getattr(settings, 'ARCTIC_ROLE_MODEL', 'arctic.Role'))),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='urole', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'swappable': 'ARCTIC_USER_ROLE_MODEL',
            },
        ),
    ]
