{% extends in_modal|yesno:"arctic/base_modal.html,arctic/base.html" %}

{% block content %}
    {% block list_content %}
        {% include "arctic/partials/base_data_table.html" %}
        {% block extra_data %}{% endblock %}
    {% endblock %}
{% endblock %}
