{% load i18n %}


{% if form.is_bound and not form.is_valid %}
    <div class="row">
        <div class="col">
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
                {% trans "Oops! We found some errors. Please check the error messages below and try again." %}
                {% if form.non_field_errors %}
                    <hr>
                    {% for error in form.non_field_errors %}
                        <p class="mb-0">
                            {{ error }}
                        </p>
                    {% endfor %}
                {% endif %}
            </div>
        </div>
    </div>
{% endif %}
