{% extends "arctic/base.html" %}
{% load i18n static arctic_tags %}

{% block title %}Access forbidden{% endblock %}


{% block body_class %}
    {{ block.super }}
    page-403
{% endblock %}


{% block content %}
<div class="row col text-center">
    <i class="fa fa-lock giant-icon"></i>
</div>
{% endblock %}
