# Generated by Django 2.1.4 on 2019-03-01 09:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('articles', '0006_auto_20190226_1342'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='image',
            name='updated_at',
        ),
        migrations.AddField(
            model_name='image',
            name='updated',
            field=models.DateTimeField(null=True),
        ),
    ]
